@@ -95,8 +95,7 @@ def init_bold_reference_wf(
         Indicates whether the ``pre_mask`` input will be set (and thus, step 1
         should be skipped).
     multiecho : :obj:`bool`
-        If multiecho data was supplied, data from the first echo
-        will be selected
+        If multiecho data was supplied, data from the first echo will be selected
     name : :obj:`str`
         Name of workflow (default: ``bold_reference_wf``)
     gen_report : :obj:`bool`
@@ -106,6 +105,8 @@ def init_bold_reference_wf(
     ------
     bold_file : str
         BOLD series NIfTI file
+    all_bold_files : str
+        Validated and header-corrected BOLD series; multiple if multi-echo
     bold_mask : bool
         A tentative brain mask to initialize the workflow (requires ``pre_mask``
         parameter set ``True``).
@@ -160,6 +161,7 @@ methodology of *fMRIPrep*.
         niu.IdentityInterface(
             fields=[
                 "bold_file",
+                "all_bold_files",
                 "raw_ref_image",
                 "skip_vols",
                 "algo_dummy_scans",
@@ -212,6 +214,7 @@ methodology of *fMRIPrep*.
         (gen_avg, outputnode, [("out_file", "raw_ref_image")]),
         (get_dummy, outputnode, [("n_dummy", "algo_dummy_scans")]),
         (val_bold, outputnode, [(("out_file", _pop), "bold_file"),
+                                ("out_file", "all_bold_files"),
                                 (("out_report", _pop), "validation_report")]),
         (enhance_and_skullstrip_bold_wf, outputnode, [
             ("outputnode.bias_corrected_file", "ref_image"),
@@ -479,8 +482,7 @@ def init_enhance_and_skullstrip_bold_wf(
         norm.inputs.fixed_image = str(bold_template)
         map_brainmask = pe.Node(
             ApplyTransforms(
-                interpolation="BSpline",
-                float=True,
+                interpolation="Linear",
                 # Use the higher resolution and probseg for numerical stability in rounding
                 input_image=str(
                     get_template(
@@ -520,7 +522,7 @@ def init_enhance_and_skullstrip_bold_wf(
     workflow.connect([
         (inputnode, check_hdr, [("in_file", "reference")]),
         (pre_dilate, check_hdr, [("out_file", "in_file")]),
-        (check_hdr, n4_correct, [("out_file", "mask_image")]),
+        (check_hdr, n4_correct, [("out_file", "weight_image")]),
         (inputnode, n4_correct, [("in_file", "input_image")]),
         (inputnode, fixhdr_unifize, [("in_file", "hdr_file")]),
         (inputnode, fixhdr_skullstrip2, [("in_file", "hdr_file")]),
