@@ -24,7 +24,7 @@
 from collections import defaultdict
 from json import dumps, loads
 from pathlib import Path
-from shutil import copytree, rmtree
+import shutil
 from pkg_resources import resource_filename as _pkgres
 import re
 
@@ -50,7 +50,7 @@ from nipype.interfaces.io import add_traits
 from templateflow.api import templates as _get_template_list
 from ..utils.bids import _init_layout, relative_to_root
 from ..utils.images import set_consumables, unsafe_write_nifti_header_and_data
-from ..utils.misc import splitext as _splitext, _copy_any
+from ..utils.misc import splitext as _splitext, _copy_any, unlink
 
 regz = re.compile(r"\.gz$")
 _pybids_spec = loads(Path(_pkgres("niworkflows", "data/nipreps.json")).read_text())
@@ -105,6 +105,10 @@ class BIDSInfo(SimpleInterface):
     This interface uses only the basename, not the path, to determine the
     subject, session, task, run, acquisition or reconstruction.
 
+    .. testsetup::
+
+        >>> data_dir_canary()
+
     >>> bids_info = BIDSInfo(bids_dir=str(datadir / 'ds054'), bids_validate=False)
     >>> bids_info.inputs.in_file = '''\
 sub-01/func/ses-retest/sub-01_ses-retest_task-covertverbgeneration_bold.nii.gz'''
@@ -224,6 +228,10 @@ class BIDSDataGrabber(SimpleInterface):
     """
     Collect files from a BIDS directory structure.
 
+    .. testsetup::
+
+        >>> data_dir_canary()
+
     >>> bids_src = BIDSDataGrabber(anat_only=False)
     >>> bids_src.inputs.subject_data = bids_collect_data(
     ...     str(datadir / 'ds114'), '01', bids_validate=False)[0]
@@ -320,6 +328,10 @@ class DerivativesDataSink(SimpleInterface):
     Saves the ``in_file`` into a BIDS-Derivatives folder provided
     by ``base_directory``, given the input reference ``source_file``.
 
+    .. testsetup::
+
+        >>> data_dir_canary()
+
     >>> import tempfile
     >>> tmpdir = Path(tempfile.mkdtemp())
     >>> tmpfile = tmpdir / 'a_temp_file.nii.gz'
@@ -630,12 +642,17 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
                             (4, 4) if self.inputs.space in STANDARD_SPACES else (2, 2)
                         )
 
-                    if curr_codes != xcodes or curr_units != units:
+                    curr_zooms = zooms = hdr.get_zooms()
+                    if "RepetitionTime" in self.inputs.get():
+                        zooms = curr_zooms[:3] + (self.inputs.RepetitionTime,)
+
+                    if (curr_codes, curr_units, curr_zooms) != (xcodes, units, zooms):
                         self._results["fixed_hdr"][i] = True
                         new_header = hdr.copy()
                         new_header.set_qform(nii.affine, xcodes[0])
                         new_header.set_sform(nii.affine, xcodes[1])
                         new_header.set_xyzt_units(*units)
+                        new_header.set_zooms(zooms)
 
                 if data_dtype == "source":  # match source dtype
                     try:
@@ -664,6 +681,7 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
                         new_header.set_data_dtype(data_dtype)
                 del nii
 
+            unlink(out_file, missing_ok=True)
             if new_data is new_header is None:
                 _copy_any(orig_file, str(out_file))
             else:
@@ -704,9 +722,11 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
                             legacy_metadata[key] = self._metadata.pop(key)
                     if legacy_metadata:
                         sidecar = out_file.parent / f"{_splitext(str(out_file))[0]}.json"
+                        unlink(sidecar, missing_ok=True)
                         sidecar.write_text(dumps(legacy_metadata, sort_keys=True, indent=2))
                 # The future: the extension is the first . and everything after
                 sidecar = out_file.parent / f"{out_file.name.split('.', 1)[0]}.json"
+                unlink(sidecar, missing_ok=True)
                 sidecar.write_text(dumps(self._metadata, sort_keys=True, indent=2))
                 self._results["out_meta"] = str(sidecar)
         return runtime
@@ -724,6 +744,10 @@ class ReadSidecarJSON(SimpleInterface):
     """
     Read JSON sidecar files of a BIDS tree.
 
+    .. testsetup::
+
+        >>> data_dir_canary()
+
     >>> fmap = str(datadir / 'ds054' / 'sub-100185' / 'fmap' /
     ...            'sub-100185_phasediff.nii.gz')
 
@@ -889,10 +913,15 @@ class BIDSFreeSurferDir(SimpleInterface):
 
             # Finesse is overrated. Either leave it alone or completely clobber it.
             if dest.exists() and self.inputs.overwrite_fsaverage:
-                rmtree(dest)
+                shutil.rmtree(dest)
             if not dest.exists():
                 try:
-                    copytree(source, dest)
+                    # Use copy instead of copy2; copy calls copymode while copy2 calls
+                    # copystat, which will preserve atime/mtime.
+                    # atime should *not* be copied to avoid triggering processes that
+                    # sweep un-accessed files.
+                    # If we want to preserve mtime, that will require a new copy function.
+                    shutil.copytree(source, dest, copy_function=shutil.copy)
                 except FileExistsError:
                     LOGGER.warning(
                         "%s exists; if multiple jobs are running in parallel"
